abacusai.codellm_embedding_constants — AbacusAI documentation

# abacusai.codellm_embedding_constants

## Classes

`CodellmEmbeddingConstants` | A dictionary of constants to be used in the autocomplete.

## Module Contents

class abacusai.codellm_embedding_constants.CodellmEmbeddingConstants(client, maxSupportedWorkspaceFiles=None, maxSupportedWorkspaceChunks=None, maxConcurrentRequests=None, fileExtensionToChunkingScheme=None, idleTimeoutSeconds=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A dictionary of constants to be used in the autocomplete.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - maxSupportedWorkspaceFiles (int) – Max supported workspace files

    - maxSupportedWorkspaceChunks (int) – Max supported workspace chunks

    - maxConcurrentRequests (int) – Max concurrent requests

    - fileExtensionToChunkingScheme (dict) – Map between the file extensions and their chunking schema

    - idleTimeoutSeconds (int) – The idle timeout without any activity before the workspace is refreshed.

  max_supported_workspace_files = None
  max_supported_workspace_chunks = None
  max_concurrent_requests = None
  file_extension_to_chunking_scheme = None
  idle_timeout_seconds = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict